aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/test/regress/expected/create_type.out4
-rw-r--r--src/test/regress/input/create_function_1.source4
-rw-r--r--src/test/regress/output/create_function_1.source4
-rw-r--r--src/test/regress/regress.c16
-rw-r--r--src/test/regress/sql/create_type.sql4
5 files changed, 16 insertions, 16 deletions
diff --git a/src/test/regress/expected/create_type.out b/src/test/regress/expected/create_type.out
index 96093477b65..0ab85a883c0 100644
--- a/src/test/regress/expected/create_type.out
+++ b/src/test/regress/expected/create_type.out
@@ -16,8 +16,8 @@ CREATE TYPE widget (
);
CREATE TYPE city_budget (
internallength = 16,
- input = city_budget_in,
- output = city_budget_out,
+ input = int44in,
+ output = int44out,
element = int4,
category = 'x', -- just to verify the system will take it
preferred = true -- ditto
diff --git a/src/test/regress/input/create_function_1.source b/src/test/regress/input/create_function_1.source
index 04511050b14..26e2227d3af 100644
--- a/src/test/regress/input/create_function_1.source
+++ b/src/test/regress/input/create_function_1.source
@@ -12,12 +12,12 @@ CREATE FUNCTION widget_out(widget)
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
-CREATE FUNCTION city_budget_in(cstring)
+CREATE FUNCTION int44in(cstring)
RETURNS city_budget
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
-CREATE FUNCTION city_budget_out(city_budget)
+CREATE FUNCTION int44out(city_budget)
RETURNS cstring
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
diff --git a/src/test/regress/output/create_function_1.source b/src/test/regress/output/create_function_1.source
index 18d2a150168..8c50d9b3099 100644
--- a/src/test/regress/output/create_function_1.source
+++ b/src/test/regress/output/create_function_1.source
@@ -12,13 +12,13 @@ CREATE FUNCTION widget_out(widget)
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
NOTICE: argument type widget is only a shell
-CREATE FUNCTION city_budget_in(cstring)
+CREATE FUNCTION int44in(cstring)
RETURNS city_budget
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
NOTICE: type "city_budget" is not yet defined
DETAIL: Creating a shell type definition.
-CREATE FUNCTION city_budget_out(city_budget)
+CREATE FUNCTION int44out(city_budget)
RETURNS cstring
AS '@libdir@/regress@DLSUFFIX@'
LANGUAGE C STRICT IMMUTABLE;
diff --git a/src/test/regress/sql/create_type.sql b/src/test/regress/sql/create_type.sql
index 9a5b5bbadd2..07061bc02a6 100644
--- a/src/test/regress/sql/create_type.sql
+++ b/src/test/regress/sql/create_type.sql
@@ -18,8 +18,8 @@ CREATE TYPE widget (
CREATE TYPE city_budget (
internallength = 16,
- input = city_budget_in,
- output = city_budget_out,
+ input = int44in,
+ output = int44out,
element = int4,
category = 'x', -- just to verify the system will take it
preferred = true -- ditto
diff --git a/src/test/regress/regress.c b/src/test/regress/regress.c
index a0058ed6a82..e14322c798a 100644
--- a/src/test/regress/regress.c
+++ b/src/test/regress/regress.c
@@ -442,19 +442,19 @@ set_ttdummy(PG_FUNCTION_ARGS)
/*
- * Type city_budget has no real-world use, but the regression tests use it.
- * It's a four-element vector of int4's.
+ * Type int44 has no real-world use, but the regression tests use it
+ * (under the alias "city_budget"). It's a four-element vector of int4's.
*/
/*
* city_budget_in - converts "num, num, ..." to internal form
*
* Note: Fills any missing positions with zeroes.
*/
-PG_FUNCTION_INFO_V1(city_budget_in);
+PG_FUNCTION_INFO_V1(int44in);
Datum
-city_budget_in(PG_FUNCTION_ARGS)
+int44in(PG_FUNCTION_ARGS)
{
char *input_string = PG_GETARG_CSTRING(0);
int32 *result = (int32 *) palloc(4 * sizeof(int32));
@@ -473,12 +473,12 @@ city_budget_in(PG_FUNCTION_ARGS)
}
/*
* city_budget_out - converts internal form to "num, num, ..."
*/
-PG_FUNCTION_INFO_V1(city_budget_out);
+PG_FUNCTION_INFO_V1(int44out);
Datum
-city_budget_out(PG_FUNCTION_ARGS)
+int44out(PG_FUNCTION_ARGS)
{
int32 *an_array = (int32 *) PG_GETARG_POINTER(0);
char *result = (char *) palloc(16 * 4);
@@ -442,19 +442,19 @@ set_ttdummy(PG_FUNCTION_ARGS)
*/
/*
- * city_budget_in - converts "num, num, ..." to internal form
+ * int44in - converts "num, num, ..." to internal form
*
* Note: Fills any missing positions with zeroes.
@@ -473,12 +473,12 @@ city_budget_in(PG_FUNCTION_ARGS)
}
/*
- * city_budget_out - converts internal form to "num, num, ..."
+ * int44out - converts internal form to "num, num, ..."
*/